// Load data from the CSV file
d3.csv("https://gist.githubusercontent.com/rohithbollareddy/8fdc5419de03c77bf60db35f5c970512/raw/6d2c7a22ee85b3b4ad1b5ee372237d3ff6e90698/studentPerformance")
  .then(function(data) {
    // Calculate the count of male and female students
    var maleCount = data.filter(function(d) { return d.gender === "male" }).length;
    var femaleCount = data.filter(function(d) { return d.gender === "female" }).length;

    // Set up the chart dimensions
    var margin = { top: 20, right: 20, bottom: 50, left: 50 };
    var width = 400 - margin.left - margin.right;
    var height = 400 - margin.top - margin.bottom;

    // Create the SVG container
    var svg = d3.select("#chart")
      .attr("width", width + margin.left + margin.right)
      .attr("height", height + margin.top + margin.bottom)
      .append("g")
        .attr("transform", "translate(" + margin.left + "," + margin.top + ")");

    // Create the x-axis scale
    var x = d3.scaleBand()
      .domain(["Male", "Female"])
      .range([0, width])
      .paddingInner(0.1);

    // Create the y-axis scale
    var y = d3.scaleLinear()
      .domain([0, d3.max([maleCount, femaleCount])])
      .range([height, 0]);

    // Add the x-axis to the chart
    svg.append("g")
      .attr("transform", "translate(0," + height + ")")
      .call(d3.axisBottom(x));

    // Add the y-axis to the chart
    svg.append("g")
      .call(d3.axisLeft(y));

    // Add the bars to the chart
    svg.selectAll(".bar")
      .data([{gender: "Male", count: maleCount}, {gender: "Female", count: femaleCount}])
      .enter().append("rect")
        .attr("class", "bar")
        .attr("x", function(d) { return x(d.gender); })
        .attr("y", function(d) { return y(d.count); })
        .attr("width", x.bandwidth())
        .attr("height", function(d) { return height - y(d.count); });
  });
